Developer Guide — CMIS Library v0.4 documentation

### Navigation

- index
- modules |
- next |
- previous |
- CMIS Library v0.4 documentation »

# Developer Guide

This page is for people who wish to contribute code to this project.

## Developer Setup

Check out the source from head, switch to the source code’s root directory, then run:
  python setup.py develop

That will set up this project’s src directory in the easy-install.pth file in site-packages.

## Release Process

Checklist:

  1. All newly-added code has a unit test

  2. All tests pass cleanly (or have good reasons for not passing)

  3. Change setup.cfg to have the appropriate tag (‘dev’, for example, or ‘’ for a stable release)

  4. Change setup.py to have the appropriate version number

  5. All changes checked in

  6. pep8 runs without much complaint
       - pep8 –ignore=E501,W601 –repeat model.py
  7. pylint runs without much complaint
       - pylint –disable-msg=C0103,R0904,R0913,C0301,W0511 cmislibtest.py

  8. Inline comments updated with changes

  9. Sphinx doc updated with changes

  10. Docs built cleanly
        - cd src/doc/src/
        - make html
  11. Setuptools build
        - python setup.py bdist sdist

  12. Upload egg and tar to Google Code downloads

  13. Make new downloads featured, old downloads deprecated

  14. Pypi update
        - python setup.py upload

  15. Tag the release in Subversion

  16. Check the cheesecake score
        - python cheesecake_index –name=cmislib

### Navigation

- index
- modules |
- next |
- previous |
- CMIS Library v0.4 documentation »